# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.storage as windows_storage

from winrt.windows.media.playlists import PlaylistFormat

Self = typing.TypeVar('Self')

@typing.final
class Playlist_Static(winrt._winrt.IInspectable_Static):
    # Windows.Foundation.IAsyncOperation`1<Windows.Media.Playlists.Playlist> Windows.Media.Playlists.Playlist::LoadAsync(Windows.Storage.IStorageFile)
    def load_async(cls, file: windows_storage.IStorageFile, /) -> windows_foundation.IAsyncOperation[Playlist]: ...

@typing.final
class Playlist(winrt.system.Object, metaclass=Playlist_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Foundation.IAsyncOperation`1<Windows.Storage.StorageFile> Windows.Media.Playlists.Playlist::SaveAsAsync(Windows.Storage.IStorageFolder,System.String,Windows.Storage.NameCollisionOption)
    def save_as_async(self, save_location: windows_storage.IStorageFolder, desired_name: str, option: windows_storage.NameCollisionOption, /) -> windows_foundation.IAsyncOperation[windows_storage.StorageFile]: ...
    # Windows.Foundation.IAsyncOperation`1<Windows.Storage.StorageFile> Windows.Media.Playlists.Playlist::SaveAsAsync(Windows.Storage.IStorageFolder,System.String,Windows.Storage.NameCollisionOption,Windows.Media.Playlists.PlaylistFormat)
    def save_as_with_format_async(self, save_location: windows_storage.IStorageFolder, desired_name: str, option: windows_storage.NameCollisionOption, playlist_format: PlaylistFormat, /) -> windows_foundation.IAsyncOperation[windows_storage.StorageFile]: ...
    # Windows.Foundation.IAsyncAction Windows.Media.Playlists.Playlist::SaveAsync()
    def save_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Storage.StorageFile> Windows.Media.Playlists.Playlist::get_Files()
    @_property
    def files(self) -> typing.MutableSequence[windows_storage.StorageFile]: ...

